@@ -41,7 +41,8 @@ class EasyLog:
 
         self.server_address = (self.host, self.port)
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        self.sock.getsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE)
+        # self.sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+        # self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
         self.__connect()
 
         self.message_log = """
@@ -75,13 +76,13 @@ is_close:{is_close}
             # TODO: 添加发送失败报警
             pass
             # DEBUG
-            # raise
+            raise
 
     def send(self, message=None):
         caller = getframeinfo(stack()[1][0])
         # DEBUG
-        # self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
-        self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
+        self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
+        # self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
 
     def close(self):
         self.__send(is_close=1)
